==> jc-1.4.0.tar.gz: ppg/code/ParserCode.h <==
// public class ppg.code.ParserCode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ff40332975ef3bc9 ppg_code_Code
// @dep_class b9e3490875f9bb05 ppg_code_ParserCode

// header file dependencies
// @dep_header ppg_code_Code

#include "ppg/code/Code.h"

#ifndef _JC_ppg_code_ParserCode_H_
#define _JC_ppg_code_ParserCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_ParserCode$sub_refs	_jc_ppg_code_ParserCode$sub_refs;
typedef struct _jc_ppg_code_ParserCode$sub_nonrefs	_jc_ppg_code_ParserCode$sub_nonrefs;
typedef struct _jc_ppg_code_ParserCode$refs	_jc_ppg_code_ParserCode$refs;
typedef struct _jc_ppg_code_ParserCode$nonrefs	_jc_ppg_code_ParserCode$nonrefs;
typedef struct _jc_ppg_code_ParserCode$object	_jc_ppg_code_ParserCode$object;

typedef const struct _jc_ppg_code_ParserCode$vmethods	_jc_ppg_code_ParserCode$vmethods;
typedef const struct _jc_ppg_code_ParserCode$vtable	_jc_ppg_code_ParserCode$vtable;
typedef const struct _jc_ppg_code_ParserCode$vtype	_jc_ppg_code_ParserCode$vtype;

// Constructors
extern void _jc_ppg_code_ParserCode$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_ppg_code_ParserCode$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_code_ParserCode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_ParserCode$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_code_ParserCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_ParserCode$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_code_ParserCode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_ParserCode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_ParserCode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_ParserCode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_ParserCode$object *);
};

// Vtable
struct _jc_ppg_code_ParserCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
	_jc_ppg_code_ParserCode$vmethods	ppg_code_ParserCode;
};

// Vtype
struct _jc_ppg_code_ParserCode$vtype {
	_jc_type			type;
	_jc_ppg_code_ParserCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_ParserCode$sub_refs {
	struct _jc_java_lang_String$object	*classname;
	struct _jc_java_lang_String$object	*extendsimpls;
};

// Reference instance fields (object)
struct _jc_ppg_code_ParserCode$refs {
    _jc_ppg_code_ParserCode$sub_refs	ppg_code_ParserCode;
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_ParserCode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_ParserCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
    _jc_ppg_code_ParserCode$sub_nonrefs	ppg_code_ParserCode;
};

// Object instance structure
struct _jc_ppg_code_ParserCode$object {
	_jc_ppg_code_ParserCode$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_ParserCode$vtype	*vtype;
	_jc_ppg_code_ParserCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_ParserCode$vtype _jc_ppg_code_ParserCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_ParserCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_ParserCode$class_object;

#endif	/* _JC_ppg_code_ParserCode_H_ */

==> jc-1.4.6.tar.gz: ppg/code/ParserCode.h <==
// public class ppg.code.ParserCode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ff40332975ef3bc9 ppg_code_Code
// @dep_class b9e3490875f9bb05 ppg_code_ParserCode

// header file dependencies
// @dep_header ppg_code_Code

#include "ppg/code/Code.h"

#ifndef _JC_ppg_code_ParserCode_H_
#define _JC_ppg_code_ParserCode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_ppg_code_ParserCode$sub_refs	_jc_ppg_code_ParserCode$sub_refs;
typedef struct _jc_ppg_code_ParserCode$sub_nonrefs	_jc_ppg_code_ParserCode$sub_nonrefs;
typedef struct _jc_ppg_code_ParserCode$refs	_jc_ppg_code_ParserCode$refs;
typedef struct _jc_ppg_code_ParserCode$nonrefs	_jc_ppg_code_ParserCode$nonrefs;
typedef struct _jc_ppg_code_ParserCode$object	_jc_ppg_code_ParserCode$object;

typedef const struct _jc_ppg_code_ParserCode$vmethods	_jc_ppg_code_ParserCode$vmethods;
typedef const struct _jc_ppg_code_ParserCode$vtable	_jc_ppg_code_ParserCode$vtable;
typedef const struct _jc_ppg_code_ParserCode$vtype	_jc_ppg_code_ParserCode$vtype;

// Constructors
extern void _jc_ppg_code_ParserCode$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_ppg_code_ParserCode$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_code_ParserCode$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_code_ParserCode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_code_ParserCode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_code_ParserCode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_code_ParserCode$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_code_ParserCode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_code_ParserCode$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_code_ParserCode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_code_ParserCode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_code_ParserCode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_code_Code$vmethods	ppg_code_Code;
	_jc_ppg_code_ParserCode$vmethods	ppg_code_ParserCode;
};

// Vtype
struct _jc_ppg_code_ParserCode$vtype {
	_jc_type			type;
	_jc_ppg_code_ParserCode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_code_ParserCode$sub_refs {
	struct _jc_java_lang_String$object	*classname;
	struct _jc_java_lang_String$object	*extendsimpls;
};

// Reference instance fields (object)
struct _jc_ppg_code_ParserCode$refs {
    _jc_ppg_code_ParserCode$sub_refs	ppg_code_ParserCode;
    _jc_ppg_code_Code$sub_refs	ppg_code_Code;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_code_ParserCode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_ppg_code_ParserCode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_code_Code$sub_nonrefs	ppg_code_Code;
    _jc_ppg_code_ParserCode$sub_nonrefs	ppg_code_ParserCode;
};

// Object instance structure
struct _jc_ppg_code_ParserCode$object {
	_jc_ppg_code_ParserCode$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_code_ParserCode$vtype	*vtype;
	_jc_ppg_code_ParserCode$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_code_ParserCode$vtype _jc_ppg_code_ParserCode$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_code_ParserCode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_code_ParserCode$class_object;

#endif	/* _JC_ppg_code_ParserCode_H_ */
